@@ -28,10 +28,15 @@ Contact: yuvraaj@gmail.com
 class SymbianCallInitiator;
 class SymbianDTMFPrivate : public CActive
 {
-public:
+private:
     SymbianDTMFPrivate (SymbianCallInitiator *p);
+
+public:
     ~SymbianDTMFPrivate ();
 
+    static SymbianDTMFPrivate* NewL(SymbianCallInitiator *p);
+    static SymbianDTMFPrivate* NewLC(SymbianCallInitiator *p);
+
     void sendDTMF (const QString &strTones);
 
 private:
@@ -40,6 +45,7 @@ private:
 
 private:
     SymbianCallInitiator *parent;
+    bool bUsable;
 };
 
 #endif // SYMBIANDTMFPRIVATE_H
